#   pdf-segmented: Generate PDFs using separate compression for foreground and background
#   Copyright (C) 2025  Lee Yingtong Li
#
#   This program is free software: you can redistribute it and/or modify
#   it under the terms of the GNU Affero General Public License as published by
#   the Free Software Foundation, either version 3 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU Affero General Public License for more details.
#
#   You should have received a copy of the GNU Affero General Public License
#   along with this program.  If not, see <https://www.gnu.org/licenses/>.

from . import CompressedLayer

from PIL import Image

from dataclasses import dataclass
import io
from typing import Optional

@dataclass
class JPEGLayer(CompressedLayer):
	data: bytes

def jpeg_compress_layer(layer: Image, jpeg_quality: Optional[float]) -> JPEGLayer:
	save_kwargs = {}
	if jpeg_quality is not None:
		save_kwargs['quality'] = jpeg_quality
	
	# Save image to JPEG
	bytesio = io.BytesIO()
	layer.save(bytesio, format='jpeg', **save_kwargs)
	
	return JPEGLayer(data=bytesio.getvalue())
